@@ -67,7 +67,7 @@ $target %dowhat readsweeps $max_processes $computype $calcprocedure %specularrat
 toil genstar solvestar integratebox filterbox__ cleanitem
 );
 
-$VERSION = '0.135';
+$VERSION = '0.153';
 $ABSTRACT = 'Sim::OPT is an optimization and parametric exploration program oriented to problem decomposition. It can be used with simulation programs receiving text files as input and emitting text files as output. It allows a free mix of sequential and parallel block coordinate searches.';
 
 #################################################################################
@@ -778,20 +778,20 @@ sub flattenbox
 
 sub integratebox
 {
-	my @arrelts = @{ $_[0] }; say $tee "IN INTEGRATEBOX \@arrelts " . dump( @arrelts ) ;
-	my %carrier = %{ $_[1] }; say $tee "IN INTEGRATEBOX \%carrier " . dump( \%carrier ) ;
+	my @arrelts = @{ $_[0] }; #say $tee "IN INTEGRATEBOX \@arrelts " . dump( @arrelts ) ;
+	my %carrier = %{ $_[1] }; #say $tee "IN INTEGRATEBOX \%carrier " . dump( \%carrier ) ;
 	my $file = $_[2];
-	my @blockelts = @{ $_[3] }; say $tee "IN INTEGRATEBOX \@blockelts @blockelts" ;
+	my @blockelts = @{ $_[3] }; #say $tee "IN INTEGRATEBOX \@blockelts @blockelts" ;
 	my @newbox;
 	foreach my $eltref ( @arrelts )
 	{
 		my @elts = @{ $eltref };
 		my $target = $elts[0]; #say $tee "IN INTEGRATEBOX Target $target" ;
-		my $righttarget = extractcase( $target, \%carrier, $file, \@blockelts ); say $tee "IN INTEGRATEBOX \$righttarget $righttarget" ;
+		my $righttarget = extractcase( $target, \%carrier, $file, \@blockelts ); #say $tee "IN INTEGRATEBOX \$righttarget $righttarget" ;
 		my $lasttarget = $elts[3]; #say $tee "IN INTEGRATEBOX lasttarget $lasttarget" ;
 		my $pasttarget = extractcase( $lasttarget, \%carrier, $file, @blockelts ); #say $tee "IN INTEGRATEBOX pasttarget $pasttarget" ;; #say $tee "IN INTEGRATEBOX Target $target" ;
 		push (@newbox, [ $righttarget, $elts[1], $elts[2], $pasttarget, $elts[2] ] );
-	} say $tee "IN INTEGRATEBOX \@newbox " . dump( @newbox ) ;
+	} #say $tee "IN INTEGRATEBOX \@newbox " . dump( @newbox ) ;
 	return ( \@newbox );
 }
 
@@ -1439,7 +1439,7 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 		@finalbox = uniq( @{ integratebox( \@bux, \%carrier, $file, \@blockelts ) } );
 	}
 
-	@finalbox = sort { $a->[0] <=> $b->[0] } @finalbox; say $tee "In DEFFILES5 \@finalbox!: " . dump ( @finalbox );
+	@finalbox = sort { $a->[0] <=> $b->[0] } @finalbox; #say $tee "In DEFFILES5 \@finalbox!: " . dump ( @finalbox );
 
 
 	setlaunch( {
@@ -1518,7 +1518,7 @@ sub exe
 	my @instances = @{ $dat{instances} }; #say $tee "IN EXE \@instances " . dump( @instances );
 	my %dirfiles = %{ $dat{dirfiles} }; #say $tee "IN EXE \%dirfiles " . dump( %dfromirfiles );
 
-	my %d = %{ $instances[0] }; say $tee "IN EXE \%d!!! " . dump( \%d );
+	my %d = %{ $instances[0] }; #say $tee "IN EXE \%d!!! " . dump( \%d );
 	my $countcase = $d{countcase}; say $tee "IN EXE \$countcase " . dump( $countcase );
 	my $countblock = $d{countblock}; say $tee "IN EXE \$countblock " . dump( $countblock );
 	my @varnumbers = @{ $d{varnumbers} }; say $tee "IN EXE \@varnumbers " . dump( @varnumbers );
@@ -1527,7 +1527,7 @@ sub exe
 	my @sourcesweeps = @{ $d{sourcesweeps} }; say $tee "IN EXE \@sourcesweeps " . dump( @sourcesweeps );
 	my @winneritems =  @{ $d{winneritems} }; say $tee "IN EXE \@winneritems " . dump( @winneritems );
 
-	my %datastruc = %{ $d{datastruc} }; say $tee "IN EXE \%datastruc " . dump( %datastruc );
+	my %datastruc = %{ $d{datastruc} }; #say $tee "IN EXE \%datastruc " . dump( %datastruc );
 	my %dowhat = %{ $d{dowhat} }; #say $tee "IN EXE \%dowhat " . dump( %dowhat );
 	my $toitem = $d{toitem}; say $tee "IN12 EXE \$toitem : " . dump( $toitem );
 	my $from = $d{from}; say $tee "IN12 EXE \$from : " . dump( $from );
@@ -2106,11 +2106,10 @@ If the search has to start from more than one block in parallel, the first block
 
 The possibility of articulating a mix of parallel and sequential searches is of absolute importance, because it makes possible to design search structures with a depth, embodying precedence, and therefore procedural time, in them. Deriving from this, there is the fact that the representation tools in question are sufficient for describing directed graphs.
 
-With the aid of Sim::OPT::Interlinear, Sim::OPT can perform block coordinate descent on metamodels in place of all or some of the ordinary blocks of a block search. In that case, a configuration file for Interlinear should also be prepared.
+Sim::OPT can perform one or more star (Jacoby) searches within a block in place of a multilevel full-factorial search. To ask for that in a configuration file, the first number in that block has to be preceded by a ">" sign, which in its turn has to be preceded by a number specifying how many star points there have to be in that block. A block, in that case, may turn out, for example, to be declared like this: ( "2>1", 2, 3).
 
-Where Sim::OPT may be fit for a task? Where a certain exploration is complex and/or when it is to be confronted through decomposition, by dividing a problem in overlapping subproblems; when there aren't slick tools suitable to decomposition-based, simulation-based optimization; when spednding a day, or two, or three setting up a model may spare months of work.
+To sayi in a Sim::OPT configuration file that a certain block has to be searched by the means of a metamodel derived from the star searches and not by the means of a multilevel full-factorial search is (once asked for one or more star searches in the block) to give to the < %dowhat > instance < $dowhat{metamodel} > the value "yes".
 
-Where it may not be suitable for the task? Due to the investment which is necessary for getting acquainted with its raw interface, for quick shots at small explorations.
 
 The program works under Linux.
 
