@@ -31,7 +31,7 @@ use Sim::OPT::Parcoord3d;
 our @ISA = qw( Exporter );
 our @EXPORT = qw( interlinear, interstart );
 
-$VERSION = '0.023';
+$VERSION = '0.033';
 $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, multivariate, discrete dataseries on the basis of gradients weighted proportionally to multidimensional distances.';
 
 #######################################################################
@@ -198,8 +198,8 @@ sub preparearr
     foreach my $line ( @lines )
     {
       chomp( $line );
-      my @row = split( /,/ , $line ); say $tee "IN PREPAREARR \@row " . dump( @row );
-      @pars = split( /_/ , $row[0] ); say $tee "IN PREPAREARR \@pars " . dump( @pars );
+      my @row = split( /,/ , $line ); #say $tee "IN PREPAREARR \@row " . dump( @row );
+      @pars = split( /_/ , $row[0] ); #say $tee "IN PREPAREARR \@pars " . dump( @pars );
       if ( $row[1] eq undef )
       {
         push ( @arr, [ $row[0], [ @pars ] ] );
@@ -246,7 +246,7 @@ sub preparearr
         push ( @arr, [ $header, [ @pars ], $row[-1], 1 ] );
       }
     }
-  } say $tee "ARR: " . dump( @arr );
+  } #say $tee "ARR: " . dump( @arr );
   return( \@arr, $optformat );
 }
 
@@ -499,23 +499,23 @@ sub calcdistgrad
 {
   my ( $el1, $elt1, $factlevels_ref, $minreq, $maxdist, $el3, $elt3, $condweight, $el, $elt ) = @_; #say $tee "777c\$el1: " . dump( $el1 ); say $tee "777c\$elt1: " . dump( $elt1 ); say $tee "777c\$minreq: " . dump( $minreq );
   my %factlevels = %{ $factlevels_ref };
-  say $tee "IN CALCDISTGRAD \$el1: " . dump( $el1 );
-  say $tee "IN CALCDISTGRAD \$elt1: " . dump( $elt1 );
-  my @diff1 = diff( \@{ $el1 }, \@{ $elt1 } ); say $tee "IN CALCDISTGRAD \@diff1: " . dump( @diff1 );
+  #say $tee "IN CALCDISTGRAD \$el1: " . dump( $el1 );
+  #say $tee "IN CALCDISTGRAD \$elt1: " . dump( $elt1 );
+  my @diff1 = diff( \@{ $el1 }, \@{ $elt1 } ); #say $tee "IN CALCDISTGRAD \@diff1: " . dump( @diff1 );
   my $dist;
   my ( @factbag, @levbag, @stepbag, @da1, @da1par, @da2, @da2par, @diff2 );
   #say $tee "777\scalar( \@diff1 ): " . dump( scalar( @diff1 ) ); say $tee "777\$minreq: " . dump( $minreq );
   #say $tee "\$minreq->[0]: " . dump( $minreq->[0] );
   if ( ( scalar( @diff1 ) > 0 ) and ( scalar( @diff1 ) <= $minreq->[0] ) )
   {
-    @diff2 = diff( \@{ $elt1 } , \@{ $el1 } ); say $tee "IN CALCDISTGRAD \@diff2: " . dump( @diff2 );
+    @diff2 = diff( \@{ $elt1 } , \@{ $el1 } ); #say $tee "IN CALCDISTGRAD \@diff2: " . dump( @diff2 );
 
-    my %h1 = map { split( /-/ , $_ ) } @diff1; say $tee "IN CALCDISTGRAD \%h1: " . dump( \%h1 );
-    @da1 = keys %h1; say $tee "IN CALCDISTGRAD \@da1: " . dump( @da1 );
-    @da1par = values %h1; say $tee "IN CALCDISTGRAD \@da1par: " . dump( @da1par );
-    my %h2 = map { split( /-/ , $_ ) } @diff2; say $tee "IN CALCDISTGRAD \%h2: " . dump( \%h2 );
-    @da2 = keys %h2; say $tee "IN CALCDISTGRAD \@da2: " . dump( @da2 );
-    @da2par = values %h2; say $tee "IN CALCDISTGRAD \@da2par: " . dump( @da2par );
+    my %h1 = map { split( /-/ , $_ ) } @diff1; #say $tee "IN CALCDISTGRAD \%h1: " . dump( \%h1 );
+    @da1 = keys %h1; # $tee "IN CALCDISTGRAD \@da1: " . dump( @da1 );
+    @da1par = values %h1; #say $tee "IN CALCDISTGRAD \@da1par: " . dump( @da1par );
+    my %h2 = map { split( /-/ , $_ ) } @diff2; #say $tee "IN CALCDISTGRAD \%h2: " . dump( \%h2 );
+    @da2 = keys %h2; #say $tee "IN CALCDISTGRAD \@da2: " . dump( @da2 );
+    @da2par = values %h2; #say $tee "IN CALCDISTGRAD \@da2par: " . dump( @da2par );
 
     my $c = 0;
     foreach my $lev1 ( @da1par )
@@ -528,7 +528,7 @@ sub calcdistgrad
         if ( $da1 == $da2 )
         {
           my $fact = $da1;
-          my $diffpar = abs( $lev1 - $lev2 ); say $tee "22 \$diffpar: " . dump( $diffpar );
+          my $diffpar = abs( $lev1 - $lev2 ); #say $tee "22 \$diffpar: " . dump( $diffpar );
           if ( ( $diffpar <= $minreq->[1] ) and ( $fact ne "" ) and ( $diffpar ne "" ) and ( $factlevels{stepsizes}{$fact} ne "" ) )
           {
             push ( @factbag, $fact );
@@ -548,8 +548,8 @@ sub calcdistgrad
 
   unless ( ( scalar( @levbag ) == 0 ) or ( scalar( @factbag ) == 0 ) or ( scalar( @stepbag ) == 0 ) )
   {
-    my $ordist = scalar( @levbag ); say $tee "IN CALCDISTGRAD \$ordist: " . dump( $ordist );
-    my $rawdist = pythagoras( \@factbag, \@levbag, \@stepbag ); say $tee "IN CALCDISTGRAD \$rawdist: " . dump( $rawdist );
+    my $ordist = scalar( @levbag ); #say $tee "IN CALCDISTGRAD \$ordist: " . dump( $ordist );
+    my $rawdist = pythagoras( \@factbag, \@levbag, \@stepbag ); #say $tee "IN CALCDISTGRAD \$rawdist: " . dump( $rawdist );
     my ( $dist, $strength );
 
     if ( $maxdist ne "" )
@@ -581,8 +581,8 @@ sub calcmaxdist
       my %hash = %{ $hash_ref }; #say $tee "00\%hash: " . dump( %hash );
       push ( @rawdists, $hash{rawdist} );
     }
-  }  say $tee "00\@rawdists: " . dump( @rawdists );
-  my $maxdist = max( @rawdists ); say $tee "00\$maxdist: " . dump( $maxdist );
+  } #say $tee "00\@rawdists: " . dump( @rawdists );
+  my $maxdist = max( @rawdists ); #say $tee "00\$maxdist: " . dump( $maxdist );
   return( $maxdist );
 }
 
@@ -593,7 +593,7 @@ sub wei
     $factlevels_ref, $minreq_forgrad, $minreq_forinclusion, $minreq_forcalc, $minreq_formerge, $maxdist ) = @_;
   my @arr = @{ $arr_ref };
   #say $tee "ARR VERY_BEFORE: " . dump(@arr);
-  my %factlevels = %{ $factlevels_ref };  say $tee "AND \%factlevels: " . dump( %factlevels );
+  my %factlevels = %{ $factlevels_ref };  #say $tee "AND \%factlevels: " . dump( %factlevels );
   # my ( %magic, %wand, %spell, %bank );
 
 
@@ -614,7 +614,7 @@ sub wei
           { #say $tee "NOW CHECKING .";
 
             my ( $res_ref ) = calcdistgrad( $el->[1], $elt->[1], \%factlevels, $minreq_forgrad, $maxdist, $el->[3], $elt->[3], $condweight, $el, $elt );
-            say $tee "\OBTAINED DIST \$res_ref: " . dump( $res_ref );
+            #say $tee "\OBTAINED DIST \$res_ref: " . dump( $res_ref );
 
             my %d;
             my ( @diff1, @diff2, @da1, @da2, @da1par, @da2par );
@@ -622,7 +622,7 @@ sub wei
 
             unless ( !keys %{ $res_ref } )
             {
-              %d = %{ $res_ref }; say $tee "FOUND \%d: " . dump( \%d );
+              %d = %{ $res_ref }; #say $tee "FOUND \%d: " . dump( \%d );
               my @diff1 = @{$d{diff1}}; #say $tee "FOUND \@diff1: " . dump( @diff1 );
               @diff2 = @{$d{diff2}}; #say $tee "FOUND \@diff2: " . dump( @diff2 );
               @da1 = @{$d{da1}}; #say $tee "FOUND \@da1: " . dump( @da1 );
@@ -662,7 +662,7 @@ sub wei
                       my @sorted = sort( $d11, $d21 );
                       my $orderedpair = join( "-", @sorted );
                       my $trio = join( "-", $d10, $pair );
-                      my $orderedtrio = join( "-", $d10, $orderedpair ); say $tee "\$orderedtrio: " . dump( $orderedtrio );
+                      my $orderedtrio = join( "-", $d10, $orderedpair ); #say $tee "\$orderedtrio: " . dump( $orderedtrio );
 
                       unless ( $trio eq "" )
                       {
@@ -726,8 +726,8 @@ sub wei
     return ( \%bank );
   }
 
-
   my %bank = %{ fillbank( \@arr, $minimumcertain, $minreq_forgrad, $maxdist, $condweight, \%factlevels ) };
+  #say $tee "IN WEI \%bank: " . dump( %bank );
 
   sub clean
   {
@@ -748,16 +748,19 @@ sub wei
         $bank{$trio}{strengths} = [ @strengths ];
       }
     }
-    return( %bank );
+    return( \%bank );
   }
-  %bank = clean( %bank );
+  %bank = %{ clean( %bank ) }; say $tee "IN WEI CLEANED \%bank: " . dump( %bank ) ;
   #my %bank =  %{ $bank_ref }; say $tee "CLEANED \%bank: " . dump( %bank );
 
   sub cyclearr
   {
-    my ( $arr_r, $minreq_forinclusion, $minreq_forgrad ) = @_;
+    my ( $arr_r, $minreq_forinclusion, $minreq_forgrad, $bank_r, $factlevels ) = @_;
     my @arr = @{ $arr_r };
+    my %bank = %{ $bank_r };
+    my %factlevels = %{ $factlevels };
     say $tee "IN cyclearr ARR: " . dump( @arr );
+
     my %wand;
     my $coun = 0;
     foreach my $el ( @arr )
@@ -914,8 +917,7 @@ sub wei
     return( \%wand );
   }
 
-  my $wand_ref = cyclearr( \@arr, $minreq_forinclusion, $minreq_forgrad );
-  my %wand = %{ $wand_ref }; say $tee "\%wand OUT: " . dump( %wand );
+  my %wand = %{ cyclearr( \@arr, $minreq_forinclusion, $minreq_forgrad, \%bank, \%factlevels ) }; say $tee "\%wand OUT: " . dump( %wand );
 
 
   my @limb0;
@@ -1402,7 +1404,14 @@ my @arr;
 
 sub interlinear
 {
-  my ( $configf, $sourcef, $metafile, $blockelts_r, $reportf ) = @_;
+  my ( $configf, $sourcef, $metafile, $blockelts_r, $reportf, $countblock ) = @_;
+  say $tee "ARRIVED IN INTERLINEAR \$configf $configf";
+  say $tee "ARRIVED IN INTERLINEAR \$sourcef $sourcef";
+  say $tee "ARRIVED IN INTERLINEAR \$metafile $metafile";
+  say $tee "ARRIVED IN INTERLINEAR \$blockelts_r ". dump( $blockelts_r );
+  say $tee "ARRIVED IN INTERLINEAR \$reportf $reportf";
+  say $tee "ARRIVED IN INTERLINEAR \$countblock $countblock";
+
   if ( $reportf ne "" ){ $report = $reportf; } #say $tee "CHECK5 \$report: " . dump( $report );
   $tee = new IO::Tee(\*STDOUT, ">>$report"); # GLOBAL ZZZ
 
@@ -1418,17 +1427,17 @@ sub interlinear
 
   my @mode = adjustmode( $maxloops, \@mode );
   open( SOURCEFILE, "$sourcefile" ) or die;
-  my @lines = <SOURCEFILE>; say $tee "REALLY \@lines: " . dump( @lines );
+  my @lines = <SOURCEFILE>; #say $tee "REALLY \@lines: " . dump( @lines );
   close SOURCEFILE;
 
-  say $tee "Preparing the dataseries.";
+  say $tee "Preparing the dataseries, IN INTERLINEAR: \$countblock $countblock";
   my $aarr_ref;
   ( $aarr_ref, $optformat ) = preparearr( @lines );
 
-  my @aarr = @{ $aarr_ref }; say $tee "REALLY \@aarr: " . dump( @aarr );
+  my @aarr = @{ $aarr_ref }; #say $tee "REALLY \@aarr: " . dump( @aarr );
 
   say $tee "Checking factors and levels.";
-  my %factlevels = %{ prepfactlev( \@aarr ) }; say $tee "IN INTERLINEAR REALLY \%factlevels: " . dump( \%factlevels );
+  my %factlevels = %{ prepfactlev( \@aarr ) }; #say $tee "IN INTERLINEAR REALLY \%factlevels: " . dump( \%factlevels );
 
   my ( $factlev_ref ) = tellstepsize( \%factlevels );
   my %factlev = %{ $factlev_ref }; say $tee "REALLY \%factlev: " . dump( %factlev );
@@ -1651,12 +1660,11 @@ Sim::OPT::Interlinear
 
 
   interlinear( "/path/to/a-pre-prepared-configfile.pl", "/path/to/a-pre-prepared-sourcefile.csv", "/path/to/the-metamodel-file-to-be-obtained" );
-  #or from the command line:
+  # Or from the command line:
   interlinear .
-  #(note the dot at the end), to use the file as a script and include the location of the source file directly in the configuration file;
-  #or again from the command line:
+  # (note the dot at the end), to use the file as a script and include the location of the source file directly in the configuration file.
+  # Or again from the command line, for beginning with a dialogue question:
   interlinear interstart
-  #to begin with a dialogue question.
 
 
 =head1 DESCRIPTION
@@ -1684,52 +1692,38 @@ The source file has to be prepared by listing in each column the values (levels)
 
 The parameter number is given by the position of the column (i.e. column 4 host parameter 4).
 
-Here below is shown an example of multivatiate dataseries of 3 parameters assuming 3 levels each. having with missing objecive function entries.
+Here below is shown an example of multivatiate dataseries of 3 parameters assuming 3 levels each. having with missing objecive function entries. The numbers preceding the objective function (which is in the last colum) are the indices of the multidimensional matrix (tensor).
 
 
 1,1,1,1.234
-
 1,2,3,2,1.500
-
 1,3,3,3
-
 2,1,3,1,1.534
-
 2,2,3,2,0.000
-
 2,3,3,0.550
-
 3,1,3,1
-
 3,2,3,2,0.670
-
 3,3,3,3
 
 
 Note that the parameter listings cannot be incomplete. Just the objective function entries can be.
-The program converts this format into the one liked by Sim::OPTS, which is the following:
+The program converts this format into the one liked by Sim::OPTS, which is the following, in which the indices of the tensor are expressed more clearly:
 
 
 1-1_2-1_3-1,9.234
-
 1-1_2-2_3-2,4.500
-
 1-1_2-3_3-3
-
 1-2_2-1_3-1,7.534
-
 1-2_2-2_3-2,0.000
-
 1-2_2-3_3-3,0.550
-
 1-3_2-1_3-1
-
 1-3_2-2_3-2,0.670
-
 1-3_2-3_3-3
 
 
 After some computations, Interlinear will output a new dataseries, with the missing values filled in.
+This dataseries can be used by OPT for the optimization of one or more blocks. This can be useful for saving computations in searches involving simulations, especially when the time required by each simulations is long, like it may happen with CFD simulations in building design.
+
 
 
 =head2 EXPORT
